<?php

namespace Litecms\Plan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Plan\Models\Plans;

class PlansPolicy
{

    /**
     * Determine if the given user can view the plans.
     *
     * @param UserPolicy $user
     * @param Plans $plans
     *
     * @return bool
     */
    public function view(UserPolicy $user, Plans $plans)
    {
        if ($user->canDo('plan.plans.view') && $user->isAdmin()) {
            return true;
        }

        return $plans->user_id == user_id() && $plans->user_type == user_type();
    }

    /**
     * Determine if the given user can create a plans.
     *
     * @param UserPolicy $user
     * @param Plans $plans
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('plan.plans.create');
    }

    /**
     * Determine if the given user can update the given plans.
     *
     * @param UserPolicy $user
     * @param Plans $plans
     *
     * @return bool
     */
    public function update(UserPolicy $user, Plans $plans)
    {
        if ($user->canDo('plan.plans.edit') && $user->isAdmin()) {
            return true;
        }

        return $plans->user_id == user_id() && $plans->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given plans.
     *
     * @param UserPolicy $user
     * @param Plans $plans
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Plans $plans)
    {
        return $plans->user_id == user_id() && $plans->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given plans.
     *
     * @param UserPolicy $user
     * @param Plans $plans
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Plans $plans)
    {
        if ($user->canDo('plan.plans.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given plans.
     *
     * @param UserPolicy $user
     * @param Plans $plans
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Plans $plans)
    {
        if ($user->canDo('plan.plans.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
